You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by iv...@apache.org on 2010/11/24 03:17:10 UTC

svn commit: r1038444 - in /wicket/trunk/wicket/src/main/java/org/apache/wicket: Component.java behavior/AbstractBehavior.java behavior/IBehavior.java markup/transformer/AbstractTransformerBehavior.java

Author: ivaynberg
Date: Wed Nov 24 02:17:10 2010
New Revision: 1038444

URL: http://svn.apache.org/viewvc?rev=1038444&view=rev
Log:
rename ibehavior#exception to ibehavior#onexception to make it consistent

Modified:
    wicket/trunk/wicket/src/main/java/org/apache/wicket/Component.java
    wicket/trunk/wicket/src/main/java/org/apache/wicket/behavior/AbstractBehavior.java
    wicket/trunk/wicket/src/main/java/org/apache/wicket/behavior/IBehavior.java
    wicket/trunk/wicket/src/main/java/org/apache/wicket/markup/transformer/AbstractTransformerBehavior.java

Modified: wicket/trunk/wicket/src/main/java/org/apache/wicket/Component.java
URL: http://svn.apache.org/viewvc/wicket/trunk/wicket/src/main/java/org/apache/wicket/Component.java?rev=1038444&r1=1038443&r2=1038444&view=diff
==============================================================================
--- wicket/trunk/wicket/src/main/java/org/apache/wicket/Component.java (original)
+++ wicket/trunk/wicket/src/main/java/org/apache/wicket/Component.java Wed Nov 24 02:17:10 2010
@@ -2412,7 +2412,7 @@ public abstract class Component
 			{
 				try
 				{
-					behavior.exception(this, ex);
+					behavior.onException(this, ex);
 				}
 				catch (Throwable ex2)
 				{

Modified: wicket/trunk/wicket/src/main/java/org/apache/wicket/behavior/AbstractBehavior.java
URL: http://svn.apache.org/viewvc/wicket/trunk/wicket/src/main/java/org/apache/wicket/behavior/AbstractBehavior.java?rev=1038444&r1=1038443&r2=1038444&view=diff
==============================================================================
--- wicket/trunk/wicket/src/main/java/org/apache/wicket/behavior/IBehavior.java (original)
+++ wicket/trunk/wicket/src/main/java/org/apache/wicket/behavior/IBehavior.java Wed Nov 24 02:17:10 2010
@@ -107,7 +107,7 @@ public interface IBehavior extends IClus
 	 * @param exception
 	 *            the unexpected exception
 	 */
-	void exception(Component component, RuntimeException exception);
+	void onException(Component component, RuntimeException exception);
 
 	/**
 	 * This method returns false if the behavior generates a callback url (for example ajax

Modified: wicket/trunk/wicket/src/main/java/org/apache/wicket/markup/transformer/AbstractTransformerBehavior.java
URL: http://svn.apache.org/viewvc/wicket/trunk/wicket/src/main/java/org/apache/wicket/markup/transformer/AbstractTransformerBehavior.java?rev=1038444&r1=1038443&r2=1038444&view=diff
==============================================================================
--- wicket/trunk/wicket/src/main/java/org/apache/wicket/markup/transformer/AbstractTransformerBehavior.java (original)
+++ wicket/trunk/wicket/src/main/java/org/apache/wicket/markup/transformer/AbstractTransformerBehavior.java Wed Nov 24 02:17:10 2010
@@ -130,11 +130,11 @@ public abstract class AbstractTransforme
 	}
 
 	/**
-	 * @see org.apache.wicket.behavior.AbstractBehavior#onException(org.apache.wicket.Component,
+	 * @see org.apache.wicket.behavior.AbstractBehavior#onHandleException(org.apache.wicket.Component,
 	 *      java.lang.RuntimeException)
 	 */
 	@Override
-	public void onException(Component component, RuntimeException exception)
+	public void onHandleException(Component component, RuntimeException exception)
 	{
 		if (webResponse != null)
 		{
--- wicket/trunk/wicket/src/main/java/org/apache/wicket/behavior/AbstractBehavior.java (original)
+++ wicket/trunk/wicket/src/main/java/org/apache/wicket/behavior/AbstractBehavior.java Wed Nov 24 02:17:10 2010
@@ -56,7 +56,7 @@ public abstract class AbstractBehavior i
 
 	/**
 	 * This method is called either by {@link #onRendered(Component)} or
 	 * {@link #onException(Component, RuntimeException)} AFTER they called their respective template
 	 * methods. Override this template method to do any necessary cleanup.
 	 */
 	public void cleanup()
@@ -71,14 +71,14 @@ public abstract class AbstractBehavior i
 	}
 
 	/**
-	 * @see org.apache.wicket.behavior.IBehavior#exception(org.apache.wicket.Component,
+	 * @see org.apache.wicket.behavior.IBehavior#onException(org.apache.wicket.Component,
 	 *      java.lang.RuntimeException)
 	 */
-	public final void exception(Component component, RuntimeException exception)
+	public final void onException(Component component, RuntimeException exception)
 	{
 		try
 		{
-			onException(component, exception);
+			onHandleException(component, exception);
 		}
 		finally
 		{
@@ -112,7 +112,7 @@ public abstract class AbstractBehavior i
 	 * @param exception
 	 *            the unexpected exception
 	 */
-	public void onException(Component component, RuntimeException exception)
+	public void onHandleException(Component component, RuntimeException exception)
 	{
 	}
 
@@ -56,7 +56,7 @@ public abstract class AbstractBehavior i
 	/**
 	 * This method is called either by {@link #onRendered(Component)} or
-	 * {@link #onException(Component, RuntimeException)} AFTER they called their respective template
+	 * {@link #onHandleException(Component, RuntimeException)} AFTER they called their respective template
 	 * methods. Override this template method to do any necessary cleanup.
 	 */

Modified: wicket/trunk/wicket/src/main/java/org/apache/wicket/behavior/IBehavior.java
URL: http://svn.apache.org/viewvc/wicket/trunk/wicket/src/main/java/org/apache/wicket/behavior/IBehavior.java?rev=1038444&r1=1038443&r2=1038444&view=diff
==============================================================================